@@ -1,5 +1,4 @@
 import json
-import logging
 
 from django.contrib.gis.db import models
 from django_extensions.db.models import TimeStampedModel
@@ -7,9 +6,6 @@ from model_utils.managers import InheritanceManager
 
 from .constants import DB_SRID
 from .file import ChecksumFile
-from .mixins import PermissionPathMixin
-
-logger = logging.getLogger(__name__)
 
 
 class SpatialEntry(models.Model):
@@ -65,7 +61,7 @@ class WhitelistedEmail(models.Model):
     email = models.EmailField()
 
 
-class SpatialAsset(SpatialEntry, TimeStampedModel, PermissionPathMixin):
+class SpatialAsset(SpatialEntry, TimeStampedModel):
     """Any spatially referenced file set.
 
     This can be any collection of files that have a spatial reference and are
@@ -75,6 +71,4 @@ class SpatialAsset(SpatialEntry, TimeStampedModel, PermissionPathMixin):
 
     """
 
-    permissions_paths = [('files', ChecksumFile)]
-
     files = models.ManyToManyField(ChecksumFile, related_name='+')
